@@ -27,7 +27,7 @@
  * list of people on the gedit Team.  
  * See the ChangeLog files for a list of changes. 
  *
- * $Id: gedit-utils.c,v 1.78 2006/06/18 08:53:35 paolo Exp $
+ * $Id: gedit-utils.c 5407 2007-01-04 13:30:58Z pborelli $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -60,22 +60,27 @@
 
 #define STDIN_DELAY_MICROSECONDS 100000
 
+/* Returns true if uri is a file: uri and is not a chained uri */
 gboolean
 gedit_utils_uri_has_file_scheme (const gchar *uri)
 {
-	gchar *canonical_uri = NULL;
+	gchar *canonical_uri;
+	gchar *tmp;
 	gboolean res;
 
 	canonical_uri = gnome_vfs_make_uri_canonical (uri);
 	g_return_val_if_fail (canonical_uri != NULL, FALSE);
 
-	res = g_str_has_prefix (canonical_uri, "file:");
-
+	tmp = gnome_vfs_get_local_path_from_uri (canonical_uri);
+	res = (tmp != NULL);
+	
 	g_free (canonical_uri);
+	g_free (tmp);
 
 	return res;
 }
 
+/* FIXME: we should check for chained URIs */
 gboolean
 gedit_utils_uri_has_writable_scheme (const gchar *uri)
 {
@@ -184,6 +189,16 @@ gedit_utils_menu_position_under_tree_view (GtkMenu  *menu,
 	}
 }
 
+/* FIXME: remove this with gtk 2.12, it has gdk_color_to_string */
+gchar * 
+gedit_gdk_color_to_string (GdkColor color)
+{
+	return g_strdup_printf ("#%04x%04x%04x",
+				color.red, 
+				color.green,
+				color.blue);
+}
+
 GtkWidget *
 gedit_gtk_button_new_with_stock_icon (const gchar *label,
 				      const gchar *stock_id)
