@@ -27,7 +27,7 @@
  * list of people on the gedit Team.  
  * See the ChangeLog files for a list of changes.
  *
- * $Id: gedit-view.c,v 1.68 2006/02/12 17:30:50 pborelli Exp $ 
+ * $Id: gedit-view.c 5403 2007-01-02 17:10:40Z sfre $ 
  */
 
 #ifdef HAVE_CONFIG_H
@@ -344,6 +344,10 @@ gedit_view_init (GeditView *view)
 
 		g_free (editor_font);
 	}
+	else
+	{
+		gedit_view_set_font (view, TRUE, NULL);
+	}
 
 	if (!gedit_prefs_manager_get_use_default_colors ())
 	{
@@ -374,6 +378,7 @@ gedit_view_init (GeditView *view)
 		      "show_margin", gedit_prefs_manager_get_display_right_margin (), 
 		      "margin", gedit_prefs_manager_get_right_margin_position (),
 		      "highlight_current_line", gedit_prefs_manager_get_highlight_current_line (), 
+		      "indent_on_tab", TRUE,
 		      "smart_home_end", FALSE, /* Never changes this */
 		      NULL);
 
@@ -387,7 +392,7 @@ gedit_view_init (GeditView *view)
 	view->priv->scroll_idle = g_idle_add ((GSourceFunc) scroll_to_cursor_on_init, view);
 	
 	view->priv->typeselect_flush_timeout = 0;	
-	view->priv->wrap_around = TRUE;		   
+	view->priv->wrap_around = TRUE;	
 }
 
 static void
@@ -397,6 +402,12 @@ gedit_view_destroy (GtkObject *object)
 
 	view = GEDIT_VIEW (object);
 
+	if (view->priv->scroll_idle > 0)
+	{
+		g_source_remove (view->priv->scroll_idle);
+		view->priv->scroll_idle = 0;
+	}
+
 	if (view->priv->search_window != NULL)
 	{
 		gtk_widget_destroy (view->priv->search_window);
@@ -425,9 +436,6 @@ gedit_view_finalize (GObject *object)
 	if (view->priv->tooltips != NULL)
 		g_object_unref (view->priv->tooltips);
 
-	if (view->priv->scroll_idle > 0)
-		g_source_remove (view->priv->scroll_idle);
-		
 	(* G_OBJECT_CLASS (gedit_view_parent_class)->finalize) (object);
 }
 
@@ -447,7 +455,6 @@ gedit_view_focus_out (GtkWidget *widget, GdkEventFocus *event)
 	return FALSE;
 }
 
-
 /**
  * gedit_view_new:
  * @doc: a #GeditDocument
@@ -778,36 +785,23 @@ gedit_view_set_font (GeditView   *view,
 		     gboolean     def, 
 		     const gchar *font_name)
 {
+	PangoFontDescription *font_desc = NULL;
+
 	gedit_debug (DEBUG_VIEW);
 
 	g_return_if_fail (GEDIT_IS_VIEW (view));
 
-	if (!def)
-	{
-		PangoFontDescription *font_desc = NULL;
+	if (def)
+		font_name = gedit_prefs_manager_get_system_font ();
 
-		g_return_if_fail (font_name != NULL);
-		
-		font_desc = pango_font_description_from_string (font_name);
-		g_return_if_fail (font_desc != NULL);
+	g_return_if_fail (font_name != NULL);
 
-		gtk_widget_modify_font (GTK_WIDGET (view), font_desc);
-		
-		pango_font_description_free (font_desc);		
-	}
-	else
-	{
-		GtkRcStyle *rc_style;
+	font_desc = pango_font_description_from_string (font_name);
+	g_return_if_fail (font_desc != NULL);
 
-		rc_style = gtk_widget_get_modifier_style (GTK_WIDGET (view));
+	gtk_widget_modify_font (GTK_WIDGET (view), font_desc);
 
-		if (rc_style->font_desc)
-			pango_font_description_free (rc_style->font_desc);
-
-		rc_style->font_desc = NULL;
-		
-		gtk_widget_modify_style (GTK_WIDGET (view), rc_style);
-	}
+	pango_font_description_free (font_desc);		
 }
 
 static void
@@ -1187,6 +1181,9 @@ search_window_key_press_event (GtkWidget   *widget,
 			       GeditView   *view)
 {
 	gboolean retval = FALSE;
+	guint modifiers;
+
+	modifiers = gtk_accelerator_get_default_mod_mask ();
 
 	/* Close window */
 	if (event->keyval == GDK_Tab)
@@ -1194,7 +1191,7 @@ search_window_key_press_event (GtkWidget   *widget,
 		hide_search_window (view, FALSE);
 		retval = TRUE;
 	}
-	
+
 	/* Close window and cancel the search */
 	if (event->keyval == GDK_Escape)
 	{
@@ -1226,7 +1223,7 @@ search_window_key_press_event (GtkWidget   *widget,
 		retval = TRUE;
 	}
 
-	if (((event->state & (GDK_CONTROL_MASK | GDK_SHIFT_MASK)) == (GDK_CONTROL_MASK | GDK_SHIFT_MASK)) && 
+	if (((event->state & modifiers) == (GDK_CONTROL_MASK | GDK_SHIFT_MASK)) && 
 	    (event->keyval == GDK_g || event->keyval == GDK_G))
 	{
 		search_again (view, TRUE);
@@ -1240,7 +1237,7 @@ search_window_key_press_event (GtkWidget   *widget,
 		retval = TRUE;
 	}
 
-	if (((event->state & (GDK_CONTROL_MASK | GDK_SHIFT_MASK)) == GDK_CONTROL_MASK) && 
+	if (((event->state & modifiers) == GDK_CONTROL_MASK) && 
 	    (event->keyval == GDK_g || event->keyval == GDK_G))
 	{
 		search_again (view, FALSE);
@@ -1457,6 +1454,65 @@ customize_for_search_mode (GeditView *view)
 				  GTK_IMAGE (icon));
 }
 
+static gboolean
+completion_func (GtkEntryCompletion *completion,
+                 const char         *key,
+		 GtkTreeIter        *iter,
+		 gpointer            data)
+{
+	gchar *item = NULL;
+	gboolean ret = FALSE;
+	GtkTreeModel *model;
+	GeditViewPrivate *priv = (GeditViewPrivate *)data;
+	const gchar *real_key;
+		
+	if (priv->search_mode == GOTO_LINE)
+		return FALSE;
+		
+	real_key = gtk_entry_get_text (GTK_ENTRY (gtk_entry_completion_get_entry (completion)));
+	
+	if (g_utf8_strlen (real_key, -1) <= MIN_SEARCH_COMPLETION_KEY_LEN)
+		return FALSE;
+		
+	model = gtk_entry_completion_get_model (completion);
+	g_return_val_if_fail (gtk_tree_model_get_column_type (model, 0) == G_TYPE_STRING, 
+			      FALSE);
+			      
+	gtk_tree_model_get (model, 
+			    iter,
+			    0, 
+			    &item,
+			    -1);
+	
+	if (item == NULL)
+		return FALSE;
+		
+	if (GEDIT_SEARCH_IS_CASE_SENSITIVE (priv->search_flags))
+	{		
+		if (!strncmp (real_key, item, strlen (real_key)))
+			ret = TRUE;
+	}
+	else
+	{
+		gchar *normalized_string;
+		gchar *case_normalized_string;
+		
+		normalized_string = g_utf8_normalize (item, -1, G_NORMALIZE_ALL);
+		case_normalized_string = g_utf8_casefold (normalized_string, -1);
+      
+      		if (!strncmp (key, case_normalized_string, strlen (key)))
+			ret = TRUE;
+ 		
+		g_free (normalized_string);
+		g_free (case_normalized_string);
+		
+	}
+	
+	g_free (item);
+	
+	return ret;	
+}
+
 static void
 ensure_search_window (GeditView *view)
 {  
@@ -1464,7 +1520,6 @@ ensure_search_window (GeditView *view)
 	GtkWidget          *vbox;
 	GtkWidget          *toplevel;
 	GtkEntryCompletion *completion;
-
 	
 	toplevel = gtk_widget_get_toplevel (GTK_WIDGET (view));
 
@@ -1553,17 +1608,24 @@ ensure_search_window (GeditView *view)
 	gtk_entry_completion_set_minimum_key_length (completion,
 						     MIN_SEARCH_COMPLETION_KEY_LEN);
 
+	gtk_entry_completion_set_popup_completion (completion, FALSE);
+	gtk_entry_completion_set_inline_completion (completion, TRUE);
+	
+	gtk_entry_completion_set_match_func (completion, 
+					     completion_func,
+					     view->priv,
+					     NULL);
+
 	/* Assign the completion to the entry */
 	gtk_entry_set_completion (GTK_ENTRY (view->priv->search_entry), 
 				  completion);
 	g_object_unref (completion);
-	
+
 	gtk_widget_realize (view->priv->search_entry);
-	
+
 	view->priv->tooltips = gtk_tooltips_new ();
-	g_object_ref (G_OBJECT (view->priv->tooltips));
-	gtk_object_sink (GTK_OBJECT (view->priv->tooltips));
-	
+	g_object_ref_sink (view->priv->tooltips);
+
 	customize_for_search_mode (view);	
 }
 
@@ -1662,7 +1724,7 @@ search_init (GtkWidget *entry,
 	     GeditView *view)
 {
 	GeditDocument *doc;
-	const gchar   *entry_text;
+	const gchar *entry_text;
 
 	/* renew the flush timeout */
 	if (view->priv->typeselect_flush_timeout != 0)
@@ -1675,7 +1737,7 @@ search_init (GtkWidget *entry,
 	}
 	
 	doc = GEDIT_DOCUMENT (gtk_text_view_get_buffer (GTK_TEXT_VIEW (view)));
-	
+			
 	entry_text = gtk_entry_get_text (GTK_ENTRY (entry));
 	
 	if (view->priv->search_mode == SEARCH)
@@ -1779,7 +1841,6 @@ reset_searched_text (GeditView *view)
 {		
 	GeditDocument *doc;
 
-	g_print ("Reset!");		
 	doc = GEDIT_DOCUMENT (gtk_text_view_get_buffer (GTK_TEXT_VIEW (view)));
 	
 	gedit_document_set_search_text (doc, "", GEDIT_SEARCH_DONT_SET_FLAGS);
