@@ -25,7 +25,7 @@
  * list of people on the gedit Team.  
  * See the ChangeLog files for a list of changes. 
  *
- * $Id: gedit-window.h,v 1.4 2005/12/12 17:27:56 pborelli Exp $
+ * $Id: gedit-window.h 5064 2006-08-07 16:42:45Z pborelli $
  */
 
 #ifndef __GEDIT_WINDOW_H__
@@ -149,32 +149,31 @@ GtkWidget	*gedit_window_get_statusbar		(GeditWindow         *window);
 GtkUIManager	*gedit_window_get_ui_manager		(GeditWindow         *window);
 
 GeditWindowState gedit_window_get_state 		(GeditWindow         *window);
-							 
+	
+GeditTab        *gedit_window_get_tab_from_uri		(GeditWindow         *window,
+							 const gchar         *uri);
 /*
  * Non exported functions
  */
 GtkWidget	*_gedit_window_get_notebook		(GeditWindow         *window);
 
-void		 _gedit_window_set_statusbar_visible	(GeditWindow         *window,
-							 gboolean             visible);
-void		 _gedit_window_set_toolbar_visible	(GeditWindow         *window,
-							 gboolean             visible);
-void		 _gedit_window_set_side_panel_visible	(GeditWindow         *window,
-							 gboolean             visible);
-void		 _gedit_window_set_bottom_panel_visible	(GeditWindow         *window,
-							 gboolean             visible);
 GeditWindow	*_gedit_window_move_tab_to_new_window	(GeditWindow         *window,
 							 GeditTab            *tab);
 gboolean	 _gedit_window_is_removing_tabs		(GeditWindow         *window);
 
-GtkWidget	*_gedit_window_get_search_panel		(GeditWindow         *window);
-
 G_CONST_RETURN gchar
 		*_gedit_window_get_default_path 	(GeditWindow         *window);
 
 void		 _gedit_window_set_saving_session_state	(GeditWindow         *window,
 							 gboolean             saving_session);
-							 
+
+/* these are in gedit-window because of screen safety */
+void		 _gedit_recent_add			(GeditWindow	     *window,
+							 const gchar         *uri,
+							 const gchar         *mime);
+void		 _gedit_recent_remove			(GeditWindow         *window,
+							 const gchar         *uri);
+
 G_END_DECLS
 
 #endif  /* __GEDIT_WINDOW_H__  */
